# idpyoidc

![CI build](https://github.com/IdentityPython/idpyoidc/workflows/idpyoidc/badge.svg)
![pypi](https://img.shields.io/pypi/v/idpyoidc.svg)
[![Downloads](https://pepy.tech/badge/idpyoidc)](https://pepy.tech/project/idpyoidc)
[![Downloads](https://pepy.tech/badge/idpyoidc/week)](https://pepy.tech/project/idpyoidc)
![License](https://img.shields.io/badge/license-Apache%202-blue.svg)

Implementation of everything OIDC and OAuth2.

idpyoidc is the 2nd layer in the
JwtConnect stack (cryptojwt, idpyoidc)

Please read the [Official Documentation](https://idpyoidc.readthedocs.io/) for getting usage examples and further informations.
